# Diamond F

A module to test diamond dependencies

## Install
```bash
$ python3 -m pip install diamond-d
```

## Usage 
```python3
from diamond import d

f.f()
```

OR

```python3
from diamond.d import d

d()
```
